@@ -17,8 +17,6 @@
 #include <kio/copyjob.h>
 #include <kio/previewjob.h>
 
-using namespace Jungle;
-
 SortModel::SortModel(QObject *parent)
     : QSortFilterProxyModel(parent)
     , m_screenshotSize(256, 256)
@@ -46,8 +44,9 @@ SortModel::SortModel(QObject *parent)
         if (!sourceModel()) {
             return;
         }
-        for (int i = 0; i <= sourceModel()->rowCount(); i++) {
-            if (Types::Image == sourceModel()->data(sourceModel()->index(i, 0, QModelIndex()), Roles::ItemTypeRole).toInt() && m_containImages == false) {
+        for (int i = 0; i < sourceModel()->rowCount(); i++) {
+            const auto itemType = sourceModel()->data(sourceModel()->index(i, 0, {}), Roles::ItemTypeRole).toInt();
+            if (Types::Image == itemType && m_containImages == false) {
                 setContainImages(true);
                 break;
             }
@@ -94,6 +93,9 @@ void SortModel::setSortRoleName(const QByteArray &name)
 
 QHash<int, QByteArray> SortModel::roleNames() const
 {
+    if (!sourceModel()) {
+        return {};
+    }
     QHash<int, QByteArray> hash = sourceModel()->roleNames();
     hash.insert(Roles::SelectedRole, "selected");
     hash.insert(Roles::Thumbnail, "thumbnail");
